<?php

namespace Appweb\Http\Controllers;

use Illuminate\Http\Request;

use Appweb\Http\Requests;
use Appweb\Http\Controllers\Controller;
use Appweb\Libraries\Util;
use Appweb\Caixa;
use Appweb\Provisionado;

class CaixaController extends Controller
{
    
    private $caixa;

    public function __construct(Caixa $caixa)
    {
        $this->caixa = $caixa;
    }

    /**
     * Display a listing of the resource.
     *
     * @return Response
     */
    public function index(Request $request)
    {
        
        if ($request->has('datainicial') && $request->has('datafinal')) {

            if ($request->has('formapagamento')) {

                $movimento = $this->caixa->whereRaw("
                    date(data) between '{$request->datainicial}' and '{$request->datafinal}'
                    ")
                    ->where('formapagamento', $request->formapagamento)
                    ->orderBy('id', 'desc')
                    ->paginate(15);
                $somaFiltro = $movimento->sum('valor');

            } else {

                $movimento = $this->caixa->whereRaw("
                    date(data) between '{$request->datainicial}' and '{$request->datafinal}'
                    ")
                    ->orderBy('id', 'desc')
                    ->paginate(15);
                $entradas   = $this->caixa->whereRaw("
                    date(data) between '{$request->datainicial}' and '{$request->datafinal}'
                    ")
                    ->where('movimento', 'E')
                    ->where('formapagamento', 'Dinheiro')
                    ->sum('valor');
                $saidas     = $this->caixa->whereRaw("
                    date(data) between '{$request->datainicial}' and '{$request->datafinal}'
                    ")
                    ->where('movimento', 'S')
                    ->where('formapagamento', 'Dinheiro')
                    ->sum('valor');
                
            }

        } else { 

            $movimento = $this->caixa->whereRaw('date(data) = CURRENT_DATE')
                ->orderBy('id', 'desc')
                ->paginate(15);
            $entradas   = $this->caixa->whereRaw('date(data) = CURRENT_DATE')
                ->where('movimento', 'E')
                ->where('formapagamento', 'Dinheiro')
                ->sum('valor');
            $saidas     = $this->caixa->whereRaw('date(data) = CURRENT_DATE')
                ->where('movimento', 'S')
                ->where('formapagamento', 'Dinheiro')
                ->sum('valor');

        }
        // dd($movimento);
        $provisionado = Util::provisionado();
        if (count($provisionado) == 0) {
            $provisionado = new Provisionado();
            $provisionado->saldo    = 0;
            $provisionado->mes      = date('m');
            $provisionado->ano      = date('Y');
            $provisionado->save();
        }
        $provisionado   = Util::provisionado();
        $saldo          = @$entradas - @$saidas;
        // dd($movimento);
        return view('pages.caixa.index', compact('saldo', 'movimento', 'provisionado', 'somaFiltro'))
            ->with("modulo", "Caixa");

    }

    /**
     * Show the form for creating a new resource.
     *
     * @return Response
     */
    public function create()
    {
        //
    }

    /**
     * Store a newly created resource in storage.
     *
     * @return Response
     */
    public function store(Request $request)
    {

        // $provisionado = Util::provisionado();
        $valormovimento = Util::toFloat($request->valormovimento);
        $movimento = new $this->caixa;
        $movimento->valor           = $valormovimento;
        $movimento->formapagamento  = 'Dinheiro';
        $movimento->data            = date('Y-m-d H:i:s');
        $movimento->observacoes     = $request->observacoes;
        if ($request->tipo == "Entrada") {
            $movimento->tipomovimento   = 'Entrada de Caixa';
            $movimento->movimento   = 'E';
        } else if ($request->tipo == "Saída") {
            $movimento->tipomovimento   = 'Saída de Caixa';
            $movimento->movimento   = 'S';
        } else if ($request->tipo == "Provisionado") {
            $provisionado = Util::provisionado();
            $provisionado->saldo = $provisionado->saldo + $valormovimento;
            $provisionado->save();
        }
        $movimento->save();
        return redirect()->back();

    }

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     * @return Response
     */
    public function resumo(Request $request)
    {
        // $resumo = Caixa::resumo2($request->data);
        $provisionado = Util::provisionado();
        $resumo = $this->caixa->whereDate('data', '=', $request->data)->groupby('tipomovimento')->get();
        $entradas = $this->caixa->whereDate('data', '=', $request->data)->where('movimento', 'E')->sum('valor');
        $saidas = $this->caixa->whereDate('data', '=', $request->data)->where('movimento', 'S')->sum('valor');
        $saldo = $entradas - $saidas;
        // dd($saldo);
        return view("pages.caixa.resumo-caixa", compact('resumo', 'provisionado', 'saldo'));
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     * @return Response
     */
    public function edit($id)
    {
        //
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  int  $id
     * @return Response
     */
    public function update($id)
    {
        //
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return Response
     */
    public function destroy($id)
    {
        //
    }
}
