<?php

namespace Appweb\Http\Controllers;

use Illuminate\Http\Request;

use Appweb\Http\Requests;
use Appweb\Http\Controllers\Controller;
use Appweb\CategoriaProduto;

class CategoriasProdutosController extends Controller
{
    private $categoria;

    public function __construct(CategoriaProduto $categoria)
    {
        $this->categoria = $categoria;
        view()->share(['modulo'=>'Categorias']);
    }

    public function index(Request $request)
    {

        if ($request->has('busca')) {
            
            $busca = $this->categoria
                ->where('descricao', 'like', '%'.$request->busca.'%')
                ->orderby("id", "desc")
                ->paginate(15);
            
        } else {
            
            $busca = $this->categoria
                ->orderby("id", "desc")
                ->paginate(15);

        }
        // dd($busca);
        return view('pages.cadastros.categorias.produtos.index', compact('busca'));

    }

    public function impressao(Request $request)
    {
        
        $dados = $this->categoria
            ->orderby('id', 'desc')
            ->get();
        $view = view('pages.cadastros.categorias.produtos.impressao', compact('dados'));
        return impressaoPDF($view, ["titulo"=>"Listagem de Lojas"]);

    }

    public function create()
    {

        return view('pages.cadastros.categorias.produtos.form');

    }

    public function edit($id="")
    {

        if (!empty($id)) {

            $categoria = $this->categoria->find($id);
            return view('pages.cadastros.categorias.produtos.form', compact('categoria'));

        } else {

            return redirect('cadastros/categorias/produtos');

        }

    }

    public function store(Request $request)
    {
        
        $regras = array(
            'descricao' => 'required',
            );
        $mensagens = array(
            'descricao.required' => 'Prencher Descrição',
            );
        
        $this->validate($request,$regras,$mensagens);
        
        $categoria = new $this->categoria;
        $categoria->descricao = $request->input("descricao");
        $categoria->status = 1;
        $categoria->save();
        
        return redirect('cadastros/categorias/produtos');

    }

    public function update(Request $request, $id="")
    {
                    
        if (!empty($id)) {
            
            $regras = array(
                'descricao' => 'required',
                );
            $mensagens = array(
                'descricao.required' => 'Prencher Descrição',
                );
            
            $this->validate($request,$regras,$mensagens);

            $categoria = $this->categoria->find($id);
            $categoria->descricao = $request->input("descricao");
            $categoria->status = ($request->input('status') == "1") ? 1 : 0;
            $categoria->save();
            
        }
        
        return redirect('cadastros/categorias/produtos');

    }

    public function destroy($id="")
    {

        if (!empty($id)) {

            $this->categoria->find($id)->delete();
            return redirect('cadastros/categorias/produtos');

        } else {

            return redirect('cadastros/categorias/produtos');

        }

    }

}
