<?php

namespace Appweb\Http\Controllers;

use Illuminate\Http\Request;

use Appweb\Http\Requests;
use Appweb\Http\Controllers\Controller;

use Appweb\Cliente;
use Appweb\Cidade;
use Appweb\Estado;

class ClientesController extends Controller
{
    
    private $cliente;

    public function __construct(Cliente $cliente)
    {
        $this->cliente = $cliente;
    }

    /**
     * Display a listing of the resource.
     *
     * @return Response
     */
    public function index(Request $request)
    {
                
        if ($request->has('busca')) {
            $busca = Cliente::where('nome', 'like', '%'.$request->busca.'%')
                ->orWhere('id', $request->busca)
                ->orderBy('nome')
                ->paginate(15);
        } else {
            $busca = Cliente::orderBy('nome')
                ->paginate(15);
        }

        return view('pages.cadastros.clientes.index')
            ->with("modulo", "Clientes")
            ->with('busca', $busca);

    }

    /**
     * Show the form for creating a new resource.
     *
     * @return Response
     */
    public function create()
    {
        
        $cidades = Cidade::where('estado', 'PE')->lists('nome', 'codigo')->toArray();
        $estados = Estado::orderBy('nome')->lists('nome', 'codigo')->toArray();
        return view('pages.cadastros.clientes.form')
            ->with('estados', $estados)
            ->with('cidades', $cidades)
            ->with("modulo", "Clientes")
            ->with('legenda', 'Cliente - Novo');

    }

    /**
     * Store a newly created resource in storage.
     *
     * @return Response
     */
    public function store(Request $request)
    {
        
        $regras = [
            'nome'=>'required', 
            // 'cpfcnpj'=>'required|unique:clientes', 
            'cpfcnpj'=>'unique:clientes', 
            ];
        $mensagens = [
            'nome.required'=>'Preencha o Nome', 
            // 'cpfcnpj.required'=>'Informe o CPF/CNPJ',
            'cpfcnpj.unique'=>'CPF/CNPJ já existe', 
            ];
        $this->validate($request,$regras,$mensagens);
        $this->cliente->create([
            'nome'=>$request->nome, 
            'endereco'=>$request->endereco, 
            'bairro'=>$request->bairro,
            'cep'=>$request->cep,
            'cidade'=>($request->has('cidade')) ? $request->cidade : null,
            'estado'=>($request->has('estado')) ? $request->estado : null,
            'sexo'=>$request->sexo,
            'telefone'=>$request->telefone, 
            'telefone2'=>$request->telefone2, 
            'celular'=>$request->celular, 
            'celular2'=>$request->celular2,
            'email'=>$request->email,
            'cpfcnpj'=>$request->cpfcnpj,
            'observacoes'=>$request->observacoes
            ]);
        return redirect('cadastros/clientes');

    }

    public function listarClientes(Request $request)
    {
        
        if ($request->has('busca')) {
            $result = $this->cliente->select("clientes.*")
                ->where('clientes.id', '=', $request->busca)
                ->orWhere('nome', 'like', '%' . $request->busca . '%')
                ->get();
        } else {
            $result = $this->cliente->select("clientes.*")
                ->join('ordens_de_servicos', 'clientes.id', '=', 'ordens_de_servicos.cliente_id')
                ->limit(20)
                ->groupby('ordens_de_servicos.cliente_id')
                ->get();
        }
        // dd($result);
        return view('pages.partials.listar-clientes', compact('result'));

    }

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     * @return Response
     */
    public function show($id)
    {
        //
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     * @return Response
     */
    public function edit($id)
    {
        $cliente = $this->cliente->find($id);
        // dd($cliente);
        $cidades = Cidade::where('estadocodigo', $cliente->estado)
            ->lists('nome', 'codigo')->toArray();
        $estados = Estado::orderBy('nome')
            ->lists('nome', 'codigo')->toArray();
        return view('pages.cadastros.clientes.form', compact('cliente', 'estados', 'cidades'))
            ->with("modulo", "Clientes")
            ->with('legenda', 'Edição');
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  int  $id
     * @return Response
     */
    public function update($id, Request $request)
    {
        // dd($request->cidade);
        $regras = [
            'nome'=>'required', 
            'cpfcnpj'=>'required', 
            ];
        $mensagens = [
            'nome.required'=>'Preencha o Nome', 
            'cpfcnpj.required'=>'Informe o CPF/CNPJ', 
            ];
        $this->validate($request,$regras,$mensagens);
        $cliente = $this->cliente->find($id);
        $cliente->update([
            'nome'=>$request->nome, 
            'endereco'=>$request->endereco, 
            'bairro'=>$request->bairro,
            'cep'=>$request->cep,
            'cidade'=>($request->has('cidade')) ? $request->cidade : null,
            'estado'=>($request->has('estado')) ? $request->estado : null,
            'sexo'=>$request->sexo,
            'telefone'=>$request->telefone, 
            'telefone2'=>$request->telefone2, 
            'celular'=>$request->celular, 
            'celular2'=>$request->celular2,
            'email'=>$request->email,
            'cpfcnpj'=>$request->cpfcnpj,
            'observacoes'=>$request->observacoes
            ]);
        return redirect('cadastros/clientes');
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return Response
     */
    public function destroy($id)
    {
        $this->cliente->find($id)->delete();
        return redirect()->back();
    }
}
