<?php

namespace Appweb\Http\Controllers;

use Illuminate\Http\Request;

use Appweb\Http\Requests;
use Appweb\Http\Controllers\Controller;
use Appweb\Libraries\Util;
use Appweb\PedidoTemp;
use Appweb\Cliente;
use Appweb\Empresa;
use Appweb\Caixa;
use Appweb\Pedido;
use Appweb\PedidoItem;
use Appweb\Promissoria;
use Appweb\Parcela;
use Appweb\Provisionado;
use Appweb\Servico;
use Appweb\Produto;
use Appweb\Cidade;
use Appweb\Estado;

use Input;
use Session;
use DB;
use Auth;

class PedidosController extends Controller
{

    public function __construct()
    {
        view()->share(['modulo'=>'Pedidos']);
    }

    public function index() 
    {
        return view('pages.pedidos.home')
            ->with("modulo", "Pedidos");
    }

    public function venda() 
    {

        if (Session::has("terminal")) :
            $terminal = Session::get("terminal");
            PedidoTemp::where("terminal", $terminal)->delete();
        else :
            $terminal = Session::put("terminal", md5(Util::gera_numero(10)));
        endif;

        $clientes = Cliente::lists('nome', 'id')->toArray();
        $cidades = Cidade::where('estado', 'PE')->lists('nome', 'codigo')->toArray();
        $estados = Estado::orderBy('nome')->lists('nome', 'codigo')->toArray();
        $catalogo = Produto::lists('descricao', 'referencia')->toArray();
        $pedido = Util::gera_numero(10);
        return view('pages.pedidos.form')
            ->with("modulo", "Pedidos")
            ->with('tela', 'vendas')
            ->with("legenda", "Venda")
            ->with("clientes", $clientes)
            ->with("cidades", $cidades)
            ->with("estados", $estados)
            ->with('catalogo', $catalogo)
            ->with("pedido", $pedido)
            ->with('terminal', $terminal);
    }

    public function servico() 
    {

        if (Session::has("terminal")) :
            $terminal = Session::get("terminal");
            PedidoTemp::where("terminal", $terminal)->delete();
        else :
            $terminal = Session::put("terminal", md5(Util::gera_numero(10)));
        endif;

        $clientes = Cliente::lists('nome', 'id')->toArray();
        $cidades = Cidade::where('estado', 'PE')->lists('nome', 'codigo')->toArray();
        $estados = Estado::orderBy('nome')->lists('nome', 'codigo')->toArray();
        $catalogo = Servico::lists('descricao', 'referencia')->toArray();
        $pedido = Util::gera_numero(10);
        return view('pages.pedidos.form')
            ->with("modulo", "Pedidos")
            ->with('tela', 'servicos')
            ->with("legenda", "Ordem de Serviço")
            ->with("clientes", $clientes)
            ->with("cidades", $cidades)
            ->with("estados", $estados)
            ->with('catalogo', $catalogo)
            ->with("pedido", $pedido)
            ->with('terminal', $terminal);

    }

    public function jsonProdutos() 
    {

        $busca = Input::get('referencia');

        $r = DB::table('produtos')
                ->where('referencia', 'like', '%' . $busca . '%')
                ->orWhere('descricao', 'like', '%' . $busca . '%')
                ->get();

        if (count($r) > 0) 
            return $r;
        else
            return 0;

    }

    public function jsonServicos() 
    {

        $busca = Input::get('referencia');

        $r = DB::table('servicos')
                ->where('referencia', '=', $busca)
                ->orWhere('descricao', 'like', '%' . $busca . '%')
                ->get();

        if (count($r) > 0) 
            return $r;
        else
            return 0;

    }

    public function clienteNovo(Request $request) 
    {
        $cliente = Cliente::create([
            'nome'=>$request->nome, 
            'endereco'=>$request->endereco, 
            'bairro'=>$request->bairro,
            'cep'=>$request->cep,
            'cidade'=>$request->cidade,
            'estado'=>$request->estado,
            'sexo'=>$request->sexo,
            'telefone'=>$request->telefone, 
            'telefone2'=>$request->telefone2, 
            'celular'=>$request->celular, 
            'celular2'=>$request->celular2,
            'email'=>$request->email,
            'vendedor'=>Auth::user()->id,
            'cpfcnpj'=>$request->cpfcnpj,
            'observacoes'=>$request->observacoes
            ]);
        return $cliente;
        
    }

    public function listarClientes() 
    {

        $clientes = Cliente::all();
        return $clientes;

    }

    public function adicionarItem(Request $request) 
    {

        $pedido = PedidoTemp::where("referencia", $request->referencia)
            ->where("pedido", $request->pedido)
            ->first();

        // return $pedidotemp->Quantidade;

        if (count($pedido) > 0) {

            // $pt = PedidoTemp::where("referencia", Input::get("referencia"))
                // ->where("pedido", Input::get("pedido"));
            $pedido->quantidade = $pedido->quantidade + $request->quantidade;
            $pedido->valor      = $request->valor;
            $pedido->subtotal   = $pedido->quantidade * $pedido->valor; 
            $pedido->save();

        } else {

            $add = new PedidoTemp();
            $add->data = date("Y-m-d");
            $add->referencia = $request->referencia;
            $add->descricao = $request->descricao;
            $add->quantidade = $request->quantidade;
            $add->unidade = $request->unidade;
            $add->valor = $request->valor;
            $add->subtotal = $request->quantidade * $request->valor;
            $add->terminal = $request->terminal;
            $add->pedido = $request->pedido;
            $add->save();

        }

    }

    public function excluirItem() 
    {
        
        $pedido = Input::get("pedido");
        $referencia = Input::get("referencia");
        PedidoTemp::where("pedido", $pedido)->where("referencia", $referencia)->delete();

    }

    public function quantidadeItens() 
    {
        
        $pedido = Input::get("pedido");
        $itens = PedidoTemp::select(DB::raw('count(*) AS ITENS'))->where("pedido", $pedido)->first();
        return $itens->ITENS;

    }

    public function totalPedidoTemp() 
    {
        
        $pedido = Input::get("pedido");
        $total = PedidoTemp::select(DB::raw('sum(quantidade*valor) AS TOTAL'))
            ->where("pedido", $pedido)
            ->first();
        return Util::decimal2($total->TOTAL);

    }

    public function listarItens() 
    {

        $pedido = Input::get('pedido');
        $itens = PedidoTemp::select(DB::raw('*, sum(quantidade*valor) as subTotal'))
            ->where("pedido", $pedido)
            ->groupBy('referencia')
            ->get();
        return view('pages.pedidos.listar-itens')
            ->with("itens", $itens);

    }

    public function listarItensTemp(Request $request) 
    {
        $po = Pedido::with('itens')->find($request->orcamento);
        // dd($po);
        PedidoTemp::where("terminal", $request->terminal)->delete();

        foreach ($po->itens as $item) {
            
            $add = new PedidoTemp();
            $add->data = date("Y-m-d");
            $add->referencia = $item->referencia;
            $add->descricao = $item->descricao;
            $add->quantidade = $item->quantidade;
            $add->unidade = $item->unidade;
            $add->valor = $item->valor;
            $add->subtotal = $item->subtotal;
            $add->terminal = $request->terminal;
            $add->pedido = $request->pedido;
            $add->save();

        }

        $itens = PedidoTemp::where("pedido", $request->pedido)
            ->get();

        return view('pages.pedidos.listar-itens', compact(
            'itens'
            ));

    }

    public function gerarPedido(Request $request)
    {
        
        // $valorLiquido = PedidoTemp::where("pedido", $request->pedido)
            // ->sum("subtotal");
        $pt = PedidoTemp::where("pedido", $request->pedido)
            ->get();
        $valorLiquido = $pt->sum('subtotal');
        // $itens = PedidoTemp::where("pedido", Input::get('pedido'))->count();
        $tela = $request->tela;
        if ($tela == 'vendas') {
            $tela = "Venda";
        } else if ($tela == 'servicos') {
            $tela = "Serviço";
        }

        if ($request->orcamento == 'on') {
            $tela = "Orçamento";
        }
        $pedido = new Pedido();
        $pedido->data           = date("Y-m-d H:i:s");
        $pedido->tipo           = $tela;
        $pedido->status         = "Entregue";
        $pedido->quantidade_itens = count($pt);
        $pedido->valorliquido   = $valorLiquido;
        $pedido->saldo          = $valorLiquido;
        $pedido->cliente_id     = $request->cliente;
        $pedido->vendedor_id    = Auth::user()->id;
        $pedido->previsaoentrega= $request->previsaoentrega;
        $pedido->previsaohorario= $request->previsaohorario;
        $pedido->observacoes    = $request->observacoes;
        $pedido->formapagamento = $request->formapagamento;
        $pedido->save();

        foreach ($pt as $item) {
            
            $subpedido = new PedidoItem();
            $subpedido->pedido = $pedido->id;
            $subpedido->referencia = $item->referencia;
            $subpedido->descricao = $item->descricao;
            $subpedido->quantidade = $item->quantidade;
            $subpedido->unidade = $item->unidade;
            $subpedido->valor = $item->valor;
            $subpedido->subtotal = $item->valor * $item->quantidade;
            $subpedido->save();

        }

        $dinheiro = Util::toFloat($request->valordinheiro);
        $cartao = Util::toFloat($request->valorcartao);
        $entradaP = Util::toFloat($request->entradapromissoria);
        $entradaPCartao = Util::toFloat($request->entradapromissoriacartao);

        if ($request->formapagamento == "Promissória") {

            $promissoriaE = Util::toFloat($request->entradapromissoria) + Util::toFloat(Util::toFloat($request->entradapromissoriacartao));
            $promissoria = Promissoria::create([
                'cliente_id'=>$request->cliente,
                'pedido_id'=>$pedido->id,
                'emissao'=>date('Y-m-d H:i:s'),
                'parcelas_promissoria'=>$request->parcelaspromissoria,
                'total'=>$valorLiquido - $promissoriaE,
                'status'=>'Pendente',
                'usuario_id'=>Auth::user()->id
                ]);
            if ($valorLiquido == 0) {
                $promissoria->status = "Quitada";
                $promissoria->save();
            }
            
            $parcela = ($valorLiquido - $entradaP) / $request->parcelaspromissoria;
            $dias = 0;
            for ($i=1; $i <= $request->parcelaspromissoria; $i++) { 
                $data = $dias+30;

                Parcela::create([
                    'pedido_id'=>$pedido->id,
                    'promissoria_id'=>$promissoria->id, 
                    'parcela'=>$i,
                    'documento'=>$pedido->id . "-" . $i,
                    'vencimento'=>date('Y-m-d', strtotime("+$data days")),
                    'valor'=>$parcela,
                    'saldo'=>$parcela,
                    'cliente_id'=>$request->cliente,
                    ]);
                $dias = 30;
            }

            if ($entradaPCartao > 0) {

                if ($entradaP > 0) {

                    $entradaPCartao = $valorLiquido - $entradaP;

                } else {

                    $entradaPCartao = $cartao;

                }

                $pgDinheiro = $entradaP;

            } else {

                $pgDinheiro = $entradaP;
                $pgCartao = $entradaPCartao;

            }

            $pedido->valorentrada = $entradaP;
            $pedido->save();

            if ($pgDinheiro > 0) {

                $provisionado = Util::provisionado();
                Caixa::create([
                    'registro' => $pedido->id,
                    'formapagamento' => "Dinheiro",
                    'tipomovimento' => 'Promissória',
                    'valor' => $pgDinheiro,
                    'data' => date("Y-m-d H:i:s"),
                    'observacoes' => "ENTRADA - " . $pedido->tipo . " (".$pedido->id.")",
                    'movimento' => "E",
                ]);
                $provisionado->saldo = $provisionado->saldo + $pgDinheiro;
                $provisionado->save();
                
            } 

            if ($pgCartao > 0) {

                Caixa::create([
                    'registro' => $pedido->id,
                    'formapagamento' => "Cartão",
                    'tipomovimento' => 'Promissória',
                    'valor' => $pgCartao,
                    'data' => date("Y-m-d H:i:s"),
                    'observacoes' => "ENTRADA - " . $pedido->tipo . " (".$pedido->id.")",
                    'movimento' => "E",
                ]);

            } 

        } else { 

            if ($cartao > 0) {

                if ($dinheiro > 0) {

                    $pgCartao = $valorLiquido - $dinheiro;

                } else {

                    $pgCartao = $cartao;

                }

                $pgDinheiro = $dinheiro;

            } else {

                $pgDinheiro = $valorLiquido;
                $pgCartao = $cartao;

            }

            if ($pgDinheiro > 0) {

                $provisionado = Util::provisionado();
                Caixa::create([
                    'registro' => $pedido->id,
                    'formapagamento' => "Dinheiro",
                    'tipomovimento' => $pedido->tipo,
                    'valor' => $pgDinheiro,
                    'data' => date("Y-m-d H:i:s"),
                    'observacoes' => $pedido->tipo . " (".$pedido->id.")",
                    'movimento' => "E",
                ]);
                $provisionado->saldo = $provisionado->saldo + $pgDinheiro;
                $provisionado->save();

                $pedido->valorentrada = $pgDinheiro;
                $pedido->save();

            } 

            if ($pgCartao > 0) {

                Caixa::create([
                    'registro' => $pedido->id,
                    'formapagamento' => "Cartão",
                    'tipomovimento' => $pedido->tipo,
                    'valor' => $pgCartao,
                    'bandeiracartao' => $request->bandeira,
                    'data' => date("Y-m-d H:i:s"),
                    'observacoes' => $pedido->tipo . " (".$pedido->id.")",
                    'movimento' => "E",
                ]);

            } 

        }

        if ($pedido->tipo == "Venda") {
            foreach ($pedido->itens as $item) {
                $produto = Produto::where('referencia', $item->referencia)->first();
                // dd($produto);
                $produto->estoque = $produto->estoque - $item->quantidade;
                $produto->save();
            }
        }

        PedidoTemp::where("terminal", $request->terminal)->delete();
        return redirect('pedidos/sucesso?pedido=' . $pedido->id);

    }

    public function sucesso(Request $request) 
    {

        $pedido = Pedido::with('itens', 'cliente')
            ->where("id", $request->pedido)
            ->first();
        // dd($pedido);
        // dd (configuracoes("DuasViasPedido"));
        $empresa = Empresa::first();
        // dd($empresa);
        return view('pages.pedidos.sucesso', compact('pedido', 'empresa'));

    }

    public function teste()
    {

        return $this->listarClientes();

    }

}
