<?php

namespace Appweb\Http\Controllers;

use Illuminate\Http\Request;

use Appweb\Http\Requests;
use Appweb\Http\Controllers\Controller;
use Appweb\Usuario;

class UsuariosController extends Controller
{
    private $usuario;

    public function __construct(Usuario $usuario)
    {
        view()->share(['modulo'=>'Usuários']);
        $this->usuario = $usuario;
    }

    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index(Request $request)
    {
        if ($request->has('busca')) {

            $busca = $this->usuario->where('nome', 'like', "%" . $request->busca . "%")
                ->orderby('nome')
                ->paginate(15);

        } else {

            $busca = $this->usuario->orderby('nome')
                ->paginate(15);

        }
        $usuarios = $this->usuario->lists('Nome', 'ID')->toArray();
        // dd($usuarios);
        return view('pages.cadastros.usuarios.index', compact('busca', 'usuarios'));
    }

    public function filtroUsuarios($request)
    {
        $usuario = $this->usuario->where(function($q) use ($request) {
            if ($request->has('usuario')) {
                $q->where('id', $request->usuario);
            }
        })
            ->get();
            return $usuario;
    }

    public function adicionar()
    {
        $vendedores = DB::table('vendedores')->select(DB::raw('CONCAT(ID," - ", Nome) as Nome'), 'ID')->orderby('ID')->lists('Nome', 'ID')->toArray();
        return view('cadastros.usuarios.form', compact('vendedores'))
            ->with("permissoes", $this->permissoes())
            ->with("acessos", []);
    }

    public function editar($id="")
    {
        if (!empty($id)) {
            $usuario    = $this->usuario->find($id);
            $vendedores = $this->vendedores
                ->select(DB::raw('CONCAT(ID," - ", Nome) as Nome'), 'ID')
                ->orderby('ID')
                ->lists('Nome', 'ID')
                ->toArray();

            return view('cadastros.usuarios.form')
                ->with("usuario", $usuario)
                ->with("vendedores", $vendedores)
                ->with("permissoes", $this->permissoes());

        } else {
            return redirect('cadastros/usuarios');
        }
    }

    public function excluir($id="")
    {
        if (!empty($id)) {
            $usuario = $this->usuario->find($id);
            $usuario->delete();
            $usuario->permissoes()->detach();
            return redirect('cadastros/usuarios');
        } else {
            return redirect('cadastros/usuarios');
        }
    }

    public function inserir(Request $request)
    {
        if (!$request->has('vendedor') && $request->nivel == "Vendedor") {
            $erro = ['mensagem-erro' => 'Escolha um vendedor.'];
            return redirect("cadastros/usuarios/adicionar")->withErrors($erro)->withInput();
        }

        $regras = [
            'nome' => 'required',
            'password' => 'required'
        ];

        $mensagens = [
            'nome.required' => 'Prencher o campo Nome',
            'password.required' => 'Preencher o campo Senha'
        ];
        
        $this->validate($request,$regras,$mensagens);

        $usuario           = new $this->usuario;
        $usuario->Nome     = $request->nome;
        $usuario->password = bcrypt($request->password);
        $usuario->Nivel    = $request->nivel;
        $usuario->Ativo    = ($request->ativo == '1') ? 1 : 0;
        $usuario->Terminal = $request->terminal;
        if ($request->has('vendedor')) {
            $usuario->Vendedor = $request->vendedor;
        }
        $usuario->save();

        $usuario->permissoes()->detach();
        $permissoes = $request->input('permissoes', []);
        foreach($permissoes as $permissao) {
            $usuario->permissoes()->attach($this->permissao->where('permissao', $permissao)->first());
        }

        return redirect('cadastros/usuarios');
    }

    public function atualizar(Request $request, $id="")
    {
        if (!empty($id)) {
            if (!$request->has('vendedor') && $request->input('nivel') == "Vendedor") {
                session()->flash('mensagem-erro', 'Escolha um vendedor.');
                return redirect()->back()->withInput();
            }

            $regras    = ['nome' => 'required'];
            $mensagens = ['nome.required' => 'Prencher o campo Nome'];
            
            $this->validate($request, $regras, $mensagens);
            
            $usuario       = $this->usuario->find($id);
            $usuario->Nome = $request->input('nome');
            if ($request->has('password')) { 
                $usuario->password = bcrypt($request->password);
            }

            $usuario->LastModified = $request->User()->Nome . " - " . date("d/m/Y H:i:s");
            $usuario->Nivel        = $request->input('nivel');
            $usuario->Ativo        = ($request->input('ativo') == '1') ? 1 : 0;
            $usuario->Terminal     = $request->input('terminal');
            $usuario->Vendedor = $request->input('vendedor', '');
            $usuario->save();

            $usuario->permissoes()->detach();
            $permissoes = $request->input('permissoes', []);
            foreach($permissoes as $permissao) {
                $usuario->permissoes()->attach($this->permissao->where('permissao', $permissao)->first());
            }
        } 
        
        return redirect()->back();
    }

    public function permissoes()
    {
        $permissoes = $this->permissao->all();
        return $permissoes;
    }

}
